@@ -111,6 +111,11 @@ UnixFd_tp_new(PyTypeObject *cls, PyObject *args, PyObject *kwargs)
         return NULL;
     }
 
+    if (variant_level < 0) {
+        PyErr_Format(PyExc_ValueError, "variant_level cannot be less than 0");
+        return NULL;
+    }
+
     status = make_fd(arg, &fd_original);
     if (status < 0)
         return NULL;
@@ -145,14 +150,12 @@ UnixFd_tp_new(PyTypeObject *cls, PyObject *args, PyObject *kwargs)
     }
 
     self = (UnixFdObject *) cls->tp_alloc(cls, 0);
-    if (!self)
-        return NULL;
-
-    self->fd = fd;
-    if (variant_level < 0) {
-        PyErr_Format(PyExc_ValueError, "variant_level cannot be less than 0");
+    if (!self) {
+        close(fd);
         return NULL;
     }
+
+    self->fd = fd;
     self->variant_level = variant_level;
 
     return (PyObject *)self;
