@@ -32,24 +32,19 @@ import time
 import logging
 import weakref
 
-try:
-    from tap.runner import TAPTestRunner
-except ImportError:
-    print('1..0 # SKIP cannot import TAPTestRunner')
-    raise SystemExit(0)
-
 import dbus
 import _dbus_bindings
 import dbus.glib
 import dbus.lowlevel
 import dbus.service
+import dbus_test_utils
 
 from dbus._compat import is_py2, is_py3
 
 try:
-    from gi.repository import GObject as gobject
+    from gi.repository import GLib
 except ImportError:
-    print('1..0 # SKIP cannot import GObject')
+    print('1..0 # SKIP cannot import GLib')
     raise SystemExit(0)
 
 logging.basicConfig()
@@ -208,7 +203,7 @@ class TestDBusBindings(unittest.TestCase):
     def testNoReply(self):
         failures = []
         report = []
-        main_loop = gobject.MainLoop()
+        main_loop = GLib.MainLoop()
         unicode_type = (str if is_py3 else unicode)
 
         def message_filter(conn, m):
@@ -261,7 +256,7 @@ class TestDBusBindings(unittest.TestCase):
         print("\n********* Testing Async Calls ***********")
 
         failures = []
-        main_loop = gobject.MainLoop()
+        main_loop = GLib.MainLoop()
 
         class async_check:
             def __init__(self, test_controler, expected_result, do_exit, **kwargs):
@@ -579,7 +574,7 @@ class TestDBusBindings(unittest.TestCase):
         dbus.Bus(private=True).close()
 
     def testTimeoutAsyncClient(self):
-        loop = gobject.MainLoop()
+        loop = GLib.MainLoop()
         passes = []
         fails = []
         def correctly_returned():
@@ -690,9 +685,6 @@ class TestDBusPythonToGLibBindings(unittest.TestCase):
             self.assertEqual(send_val, recv_val.object)
 """
 if __name__ == '__main__':
-    gobject.threads_init()
     dbus.glib.init_threads()
 
-    runner = TAPTestRunner()
-    runner.set_stream(True)
-    unittest.main(testRunner=runner)
+    dbus_test_utils.main()
